@@ -25,6 +25,10 @@
 
 // Konsole
 #include "CharacterColor.h"
+#include "CharacterWidth.h"
+
+// Qt
+#include <QVector>
 
 namespace Konsole {
 typedef unsigned char LineProperty;
@@ -155,6 +159,27 @@ public:
             return QChar(character).isSpace();
         }
     }
+
+    inline int width() const {
+        return width(character);
+    }
+
+    static int width(uint ucs4) {
+        return characterWidth(ucs4);
+    }
+
+    static int stringWidth(const uint *ucs4Str, int len) {
+        int w = 0;
+        for (int i = 0; i < len; ++i) {
+            w += width(ucs4Str[i]);
+        }
+        return w;
+    }
+
+    inline static int stringWidth(const QString &str) {
+        auto ucs4Str = str.toUcs4();
+        return stringWidth(ucs4Str.constData(), ucs4Str.length());
+    }
 };
 
 inline bool operator ==(const Character &a, const Character &b)
