@@ -80,6 +80,8 @@ TabbedViewContainer::TabbedViewContainer(ViewManager *connectedViewManager, QWid
        closeCurrentTab();
     });
 
+    connect(tabBar(), &QTabBar::currentChanged, this,
+        &Konsole::TabbedViewContainer::currentTabChanged);
     connect(tabBar(), &QTabBar::tabBarDoubleClicked, this,
         &Konsole::TabbedViewContainer::tabDoubleClicked);
     connect(tabBar(), &QTabBar::customContextMenuRequested, this,
@@ -199,6 +201,8 @@ void TabbedViewContainer::konsoleConfigChanged()
 
     if (KonsoleSettings::tabBarUseUserStyleSheet()) {
         setCssFromFile(KonsoleSettings::tabBarUserStyleSheetFile());
+    } else {
+        setStyleSheet(QString());
     }
 }
 
@@ -224,6 +228,9 @@ void TabbedViewContainer::setCssFromFile(const QUrl &url)
 
 void TabbedViewContainer::moveActiveView(MoveDirection direction)
 {
+    if (count() < 2) { // return if only one view
+        return;
+    }
     const int currentIndex = indexOf(currentWidget());
     int newIndex = direction  == MoveViewLeft ? qMax(currentIndex - 1, 0) : qMin(currentIndex + 1, count() - 1);
 
