@@ -116,7 +116,7 @@ extern "C" int Q_DECL_EXPORT kdemain(int argc, char *argv[])
                      i18nc("@title", "Terminal emulator"),
                      KAboutLicense::GPL_V2,
                      i18nc("@info:credit", "(c) 1997-2017, The Konsole Developers"),
-                     QStringLiteral(),
+                     QString(),
                      QStringLiteral("https://konsole.kde.org/"));
     fillAboutData(about);
 
@@ -194,7 +194,7 @@ extern "C" int Q_DECL_EXPORT kdemain(int argc, char *argv[])
     } else {
         // Do not finish starting Konsole due to:
         // 1. An argument was given to just printed info
-        // 2. An invalid situation ocurred
+        // 2. An invalid situation occurred
         const bool continueStarting = (konsoleApp.newInstance() != 0);
         if (!continueStarting) {
             delete app;
